@@ -128,9 +128,6 @@ class YieldFunction(metaclass=abc.ABCMeta):
 
         initial_params = initial_params or {}
 
-        # print(f'fitting_param_names: {fitting_param_names}')
-        # print(f'initial_params: {initial_params}')
-
         if initial_params:
             for k, initial_guess in initial_params.items():
                 if k not in fitting_param_names:
@@ -162,25 +159,9 @@ class YieldFunction(metaclass=abc.ABCMeta):
                 idx = fitting_param_names.index('equivalent_stress')
                 initial_params_all[idx] = 50e6
 
-            if 'exponent' in fitting_param_names:
-                bounds = (
-                    [-2] * (len(initial_params_all) - 1) + [1],
-                    [+2] * (len(initial_params_all) - 1) + [8],
-                )
-            else:
-                bounds = (
-                    [-2] * len(initial_params_all),
-                    [+2] * len(initial_params_all),
-                )
-
-            # print(f'initial_params_all: {initial_params_all}')
-            # print(f'fitting_param_names: {fitting_param_names}')
-            # print(f'bounds:\n{bounds}')
-
             fit = least_squares(
                 cls.residual,
                 initial_params_all,
-                bounds=bounds,
                 kwargs=dict(
                     stress_states=stress_states,
                     fitting_param_names=fitting_param_names,
